/*

People library by ACWraith

This library divides "people" into three categories and provides a framework for output.
The library does not actually care what you are calling people.
It just sorts them into players, people on the waiting list, or spectators.
(Type-dependent procedures, like mass winset commands, check for clients first.)
Changes in categories can be automatically displayed.

Consider the prefix p_ to be reserved.

/////////////////////////////////////////////////////////////////////////////////////////////////

p_PeopleHandler

	p_GetListOfAll()
		Returns all people in the handler.
	p_IsListed(Candidate)
		Returns whether or not Candidate is listed as a player, waiter or spectator.

	p_DisplayPeopleToViewer(Viewer)
		Display the people to Viewer.
		By default all this does is return TRUE if Viewer is capable of viewing the display.
		You'll want to define it for your interface.
	p_DisplayPeopleToAll(AutomatedCall=FALSE)
		Display the people to everyone.
		By default, this does nothing.
		You'll want to define it for your interface.
		If called internally, AutomatedCall is TRUE.
	p_OutputAll(Message,Control)
		Send Message to all players, waiters, and spectators through Control.
	p_WinsetAll(Control,Params)
		Set the skin Control of all players, waiters, and spectators to use Params.

	p_Reconnected(Person)
		Adds the proper interface back to Person.  Call this when logging in.
	p_Disconnected(Person)
		This does nothing by default.  You may want to call this when logging out anyway.
		Library extensions may use it.


	Player procs:
		p_AddPlayer(Candidate,AutomatedCall=FALSE)
			Add Candidate as a player and return TRUE on success.
			Candidate will no longer be a waiter nor a spectator.
			If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.
		p_RemovePlayer(Candidate,AutomatedCall=FALSE)
			Stops the handler from regarding Candidate as a player.
			If called internally, AutomatedCall is TRUE.
			If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.

		p_GetListOfPlayers()
			Returns a copy of the list of players.
		p_GetNumberOfPlayers()
			Returns the number of players.
		p_IsPlaying(Candidate)
			Returns whether or not Candidate is a player.

		p_AddInterfacePlayer(Candidate)
			Give the player interface to Candidate.
			This is called automatically by p_AddPlayer() and p_Reconnected().
			By default, this returns FALSE if Candidate is not a mob with a client.
		p_OutputPlayers(Message,Control)
			Sends Message to all players through Control.
		p_RemoveInterfacePlayer(Candidate)
			Remove the player interface from Candidate.
			This is called automatically by p_RemovePlayer().
			By default, this returns FALSE if Candidate is not a mob with a client.
		p_WinsetPlayers(Control,Params)
			Set the skin Control of all players to use Params.

	Spectator procs:
		p_AddSpectator(Candidate,AutomatedCall=FALSE)
			Add Candidate as a spectator and return TRUE on success.
			Candidate will no longer be a waiter nor a player.
			If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.
		p_RemoveSpectator(Candidate,AutomatedCall=FALSE)
			Stops the handler from regarding Candidate as a spectator.
			If called internally, AutomatedCall is TRUE.
			If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.

		p_GetListOfSpectators()
			Returns a copy of the list of spectators.
		p_GetNumberOfSpectators()
			Returns the number of spectators.
		p_IsSpectating(Candidate)
			Returns whether or not Candidate is spectating.

		p_AddInterfaceSpectator(Candidate)
			Give the player interface to Candidate.
			This is called automatically by p_AddSpectator() and p_Reconnected().
			By default, this returns FALSE if Candidate is not a mob with a client.
		p_OutputSpectators(Message,Control)
			Sends Message to all spectators through Control.
		p_RemoveInterfaceSpectator(Candidate)
			Remove the player interface from Candidate.
			This is called automatically by p_RemoveSpectator().
			By default, this returns FALSE if Candidate is not a mob with a client.
		p_WinsetSpectators(Control,Params)
			Set the skin Control of all spectators to use Params.

	Waiting list procs:
		p_AddWaiter(Candidate,AutomatedCall=FALSE)
			Adds Candidate to the waiting list and return TRUE on success.
			Candidate will no longer be a player nor a spectator.
			If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.
		p_RemoveWaiter(Candidate,AutomatedCall=FALSE)
			Removes Candidate from the waiting list.
			If called internally, AutomatedCall is TRUE.
			If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.

		p_GetListOfWaiters()
			Returns a copy of the list of waiters.
		p_GetNumberOfWaiters()
			Returns the number of waiters.
		p_IsWaiting(Candidate)
			Returns whether or not Candidate is in the waiting list.

		p_AddInterfaceWaiter(Candidate)
			Give the player interface to Candidate.
			This is called automatically by p_AddWaiter() and p_Reconnected().
			By default, this returns FALSE if Candidate is not a mob with a client.
		p_OutputWaiters(Message,Control)
			Sends Message to everyone in the waiting list through Control.
		p_RemoveInterfaceWaiter(Candidate)
			Remove the player interface from Candidate.
			This is called automatically by p_RemoveWaiter().
			By default, this returns FALSE if Candidate is not a mob with a client.
		p_WinsetWaiters(Control,Params)
			Set the skin Control of everyone in the waiting list to use Params.

*/