p_PeopleHandler

	//============================================================================================
	var/list/p_players

	//============================================================================================
	proc
		//----------------------------------------------------------------------------------------
		//	Give the player interface to Candidate.
		//	This is called automatically by p_AddPlayer() and p_Reconnected().
		//	By default, this returns FALSE if Candidate is not a mob with a client.
		p_AddInterfacePlayer(Candidate)
			if ( !ismob(Candidate) )	return FALSE
			var/mob/M					= Candidate
			return !isnull(M.client)

		//----------------------------------------------------------------------------------------
		//	Add Candidate as a player and return TRUE on success.
		//	Candidate will no longer be a waiter nor a spectator.
		//	If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.
		p_AddPlayer(Candidate,AutomatedCall=FALSE)
			if ( src.p_IsPlaying(Candidate) )		return FALSE
			src.p_players							+= Candidate
			if ( src.p_IsWaiting(Candidate) )		src.p_RemoveWaiter(Candidate,TRUE)
			if ( src.p_IsSpectating(Candidate) )	src.p_RemoveSpectator(Candidate,TRUE)
			src.p_AddInterfacePlayer(Candidate)
			if (!AutomatedCall)						src.p_DisplayPeopleToAll(TRUE)
			return TRUE

		//----------------------------------------------------------------------------------------
		//	Returns a copy of the list of players.
		p_GetListOfPlayers()
			return src.p_players.Copy()

		//----------------------------------------------------------------------------------------
		//	Returns the number of players.
		p_GetNumberOfPlayers()
			return src.p_players.len

		//----------------------------------------------------------------------------------------
		//	Returns whether or not Candidate is a player.
		p_IsPlaying(Candidate)
			return (Candidate in src.p_players)

		//----------------------------------------------------------------------------------------
		//	Sends Message to all players through Control.
		p_OutputPlayers(Message,Control)
			src.p_players	<< output(Message,Control)

		//----------------------------------------------------------------------------------------
		//	Remove the player interface from Candidate.
		//	This is called automatically by p_RemovePlayer().
		//	By default, this returns FALSE if Candidate is not a mob with a client.
		p_RemoveInterfacePlayer(Candidate)
			if ( !ismob(Candidate) )	return FALSE
			var/mob/M					= Candidate
			return !isnull(M.client)

		//----------------------------------------------------------------------------------------
		//	Stops the handler from regarding Candidate as a player.
		//	If called internally, AutomatedCall is TRUE.
		//	If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.
		p_RemovePlayer(Candidate,AutomatedCall=FALSE)
			if ( !src.p_IsPlaying(Candidate) )	return FALSE
			src.p_players						-= Candidate
			src.p_RemoveInterfacePlayer(Candidate)
			if (!AutomatedCall)					src.p_DisplayPeopleToAll(TRUE)
			return TRUE

		//----------------------------------------------------------------------------------------
		//	Set the skin Control of all players to use Params.
		p_WinsetPlayers(Control,Params)
			for(var/client/C in src.p_players)	winset(C,Control,Params)
			for(var/mob/M in src.p_players)		if(M.client)	winset(M,Control,Params)
