p_PeopleHandler

	//============================================================================================
	var/list/p_spectators

	//============================================================================================
	proc
		//----------------------------------------------------------------------------------------
		//	Give the player interface to Candidate.
		//	This is called automatically by p_AddSpectator() and p_Reconnected().
		//	By default, this returns FALSE if Candidate is not a mob with a client.
		p_AddInterfaceSpectator(Candidate)
			if ( !ismob(Candidate) )	return FALSE
			var/mob/M					= Candidate
			return !isnull(M.client)

		//----------------------------------------------------------------------------------------
		//	Add Candidate as a spectator and return TRUE on success.
		//	Candidate will no longer be a waiter nor a player.
		//	If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.
		p_AddSpectator(Candidate,AutomatedCall=FALSE)
			if ( src.p_IsSpectating(Candidate) )	return FALSE
			src.p_spectators						+= Candidate
			if ( src.p_IsWaiting(Candidate) )		src.p_RemoveWaiter(Candidate,TRUE)
			if ( src.p_IsPlaying(Candidate) )		src.p_RemovePlayer(Candidate,TRUE)
			src.p_AddInterfaceSpectator(Candidate)
			if (!AutomatedCall)						src.p_DisplayPeopleToAll(TRUE)
			return TRUE

		//----------------------------------------------------------------------------------------
		//	Returns a copy of the list of spectators.
		p_GetListOfSpectators()
			return src.p_spectators.Copy()

		//----------------------------------------------------------------------------------------
		//	Returns the number of spectators.
		p_GetNumberOfSpectators()
			return src.p_spectators.len

		//----------------------------------------------------------------------------------------
		//	Returns whether or not Candidate is spectating.
		p_IsSpectating(Candidate)
			return (Candidate in src.p_spectators)

		//----------------------------------------------------------------------------------------
		//	Sends Message to all spectators through Control.
		p_OutputSpectators(Message,Control)
			src.p_spectators	<< output(Message,Control)

		//----------------------------------------------------------------------------------------
		//	Remove the player interface from Candidate.
		//	This is called automatically by p_RemoveSpectator().
		//	By default, this returns FALSE if Candidate is not a mob with a client.
		p_RemoveInterfaceSpectator(Candidate)
			if ( !ismob(Candidate) )	return FALSE
			var/mob/M					= Candidate
			return !isnull(M.client)

		//----------------------------------------------------------------------------------------
		//	Stops the handler from regarding Candidate as a spectator.
		//	If called internally, AutomatedCall is TRUE.
		//	If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.
		p_RemoveSpectator(Candidate,AutomatedCall=FALSE)
			if ( !src.p_IsSpectating(Candidate) )	return FALSE
			src.p_spectators						-= Candidate
			src.p_RemoveInterfaceSpectator(Candidate)
			if (!AutomatedCall)						src.p_DisplayPeopleToAll(TRUE)
			return TRUE

		//----------------------------------------------------------------------------------------
		//	Set the skin Control of all spectators to use Params.
		p_WinsetSpectators(Control,Params)
			for(var/client/C in src.p_spectators)	winset(C,Control,Params)
			for(var/mob/M in src.p_spectators)		if(M.client)	winset(M,Control,Params)
