p_PeopleHandler

	//============================================================================================
	var/list/p_waiters

	//============================================================================================
	proc
		//----------------------------------------------------------------------------------------
		//	Give the player interface to Candidate.
		//	This is called automatically by p_AddWaiter() and p_Reconnected().
		//	By default, this returns FALSE if Candidate is not a mob with a client.
		p_AddInterfaceWaiter(Candidate)
			if ( !ismob(Candidate) )	return FALSE
			var/mob/M					= Candidate
			return !isnull(M.client)

		//----------------------------------------------------------------------------------------
		//	Adds Candidate to the waiting list and return TRUE on success.
		//	Candidate will no longer be a player nor a spectator.
		//	If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.
		p_AddWaiter(Candidate,AutomatedCall=FALSE)
			if ( src.p_IsWaiting(Candidate) )		return FALSE
			src.p_waiters							+= Candidate
			if ( src.p_IsPlaying(Candidate) )		src.p_RemovePlayer(Candidate,TRUE)
			if ( src.p_IsSpectating(Candidate) )	src.p_RemoveSpectator(Candidate,TRUE)
			src.p_AddInterfaceWaiter(Candidate)
			if (!AutomatedCall)						src.p_DisplayPeopleToAll(TRUE)
			return TRUE

		//----------------------------------------------------------------------------------------
		//	Returns a copy of the list of waiters.
		p_GetListOfWaiters()
			return src.p_waiters.Copy()

		//----------------------------------------------------------------------------------------
		//	Returns the number of waiters.
		p_GetNumberOfWaiters()
			return src.p_waiters.len

		//----------------------------------------------------------------------------------------
		//	Returns whether or not Candidate is in the waiting list.
		p_IsWaiting(Candidate)
			return (Candidate in src.p_waiters)

		//----------------------------------------------------------------------------------------
		//	Sends Message to everyone in the waiting list through Control.
		p_OutputWaiters(Message,Control)
			src.p_waiters	<< output(Message,Control)

		//----------------------------------------------------------------------------------------
		//	Remove the player interface from Candidate.
		//	This is called automatically by p_RemoveWaiter().
		//	By default, this returns FALSE if Candidate is not a mob with a client.
		p_RemoveInterfaceWaiter(Candidate)
			if ( !ismob(Candidate) )	return FALSE
			var/mob/M					= Candidate
			return !isnull(M.client)

		//----------------------------------------------------------------------------------------
		//	Removes Candidate from the waiting list.
		//	If called internally, AutomatedCall is TRUE.
		//	If AutomatedCall is FALSE, then p_DisplayPeopleToAll() is called.
		p_RemoveWaiter(Candidate,AutomatedCall=FALSE)
			if ( !src.p_IsWaiting(Candidate) )	return FALSE
			src.p_waiters						-= Candidate
			src.p_RemoveInterfaceWaiter(Candidate)
			if (!AutomatedCall)					src.p_DisplayPeopleToAll(TRUE)
			return TRUE

		//----------------------------------------------------------------------------------------
		//	Set the skin Control of everyone in the waiting list to use Params.
		p_WinsetWaiters(Control,Params)
			for(var/client/C in src.p_waiters)	winset(C,Control,Params)
			for(var/mob/M in src.p_waiters)		if(M.client)	winset(M,Control,Params)
